summaryrefslogtreecommitdiff
path: root/epan/addr_resolv.h
diff options
context:
space:
mode:
authorMichael Mann <mmann78@netscape.net>2015-01-04 21:40:05 -0500
committerMichael Mann <mmann78@netscape.net>2015-01-05 13:55:04 +0000
commit22b4ec91c006fec65e655ccbb0dbbc32438f820b (patch)
tree033dc9de28b8a79550a4dd769fcfb249df4be38c /epan/addr_resolv.h
parent9a7318a184e25e08d1c8449e3f826e0a5c66ca3b (diff)
downloadwireshark-22b4ec91c006fec65e655ccbb0dbbc32438f820b.tar.gz
Replace ep_display_to_address with wmem equivalent display_to_address.
Almost all instances require using "manual" memory management, but it gets some ep_ calls out of the GUI. Change-Id: Ifa7303766b08d09442ccf3d7063cbe061578ecd9 Reviewed-on: https://code.wireshark.org/review/6318 Reviewed-by: Michael Mann <mmann78@netscape.net>
Diffstat (limited to 'epan/addr_resolv.h')
-rw-r--r--epan/addr_resolv.h20
1 files changed, 3 insertions, 17 deletions
diff --git a/epan/addr_resolv.h b/epan/addr_resolv.h
index 140cc8703c..9051362f2a 100644
--- a/epan/addr_resolv.h
+++ b/epan/addr_resolv.h
@@ -132,7 +132,8 @@ extern gchar *ep_dccp_port_to_display(guint port);
*/
WS_DLL_PUBLIC gchar *ep_sctp_port_to_display(guint port);
/* ep_address_to_display takes as input an "address", as defined in address.h */
/* it returns a string that contains: */
/* - if the address is of a type that can be translated into a name, and the user */
/* has activated name resolution, the translated name */
@@ -140,23 +141,8 @@ WS_DLL_PUBLIC gchar *ep_sctp_port_to_display(guint port);
/* - if the address is of any other type, the result of ep_address_to_str on the argument, */
/* which should be a string representation for the answer -e.g. "10.10.10.10" for IPv4 */
/* address 10.10.10.10 */
-
-WS_DLL_PUBLIC
-const gchar *ep_address_to_display(const address *addr);
-
-/*
- * wmem_address_to_display is the same as ep_address_to_display above, but
- * using the wmem scope for memory management.
- */
WS_DLL_PUBLIC
-const gchar *wmem_address_to_display(wmem_allocator_t *allocator, const address *addr);
-
-/* get_addr_name_buf solves an address in the same way as ep_address_to_display above */
-/* The difference is that get_addr_name_buf takes as input a buffer, into which it puts */
-/* the result which is always NUL ('\0') terminated. The buffer should be large enough to */
-/* contain size characters including the terminator */
-
-void get_addr_name_buf(const address *addr, gchar *buf, gsize size);
+const gchar *address_to_display(wmem_allocator_t *allocator, const address *addr);
const gchar *get_addr_name(const address *addr);
@@ -132,7 +132,8 @@ extern gchar *ep_dccp_port_to_display(guint port);
*/
WS_DLL_PUBLIC gchar *ep_sctp_port_to_display(guint port);
-/* ep_address_to_display takes as input an "address", as defined in address.h */
+/*
+ * address_to_display takes as input an "address", as defined in address.h */
/* it returns a string that contains: */
/* - if the address is of a type that can be translated into a name, and the user */